/* tpb - program to use the IBM ThinkPad(tm) special keys
 * Copyright (C) 2002-2008 Markus Braun <markus.braun@krawel.de>
 *
 * This file is part of tpb.
 *
 * tpb is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * tpb is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with tpb; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __TPB_H__
#define __TPB_H__

#if ENABLE_NLS
#include <libintl.h>
#define _(String) gettext (String)
#else /* ENABLE_NLS */
#define _(String) (String)
#endif /* ENABLE_NLS */

#define MAX_VOLUME 100
#define CALLBACK_CMD_LENGTH 256
#define CALLBACK_CMD_ARGS 30

/* all known X keycodes for special keys */
typedef enum {
  KEYCODE_HOME            = 178,
  KEYCODE_SEARCH          = 229,
  KEYCODE_MAIL            = 236,
  KEYCODE_FAVORITES       = 230,
  KEYCODE_RELOAD          = 231,
  KEYCODE_ABORT           = 232,

  KEYCODE_BACKWARD        = 234,
  KEYCODE_FORWARD         = 233,

  KEYCODE_SKIP_BACKWARD   = 144,
  KEYCODE_SKIP_FORWARD    = 153,
  KEYCODE_PLAY            = 162,
  KEYCODE_STOP            = 164,

  KEYCODE_MUTE            = 160,
  KEYCODE_VOLUME_DOWN     = 174,
  KEYCODE_VOLUME_UP       = 176,

  KEYCODE_LOCK            = 146,
  KEYCODE_BATTERY         = 241,
  KEYCODE_SLEEP           = 223,
  KEYCODE_WIRELESS        = 666, // TODO: doesn't show any change on my T61
  KEYCODE_DISPLAY         = 214,
  KEYCODE_TRACKPOINT      = 249,
  KEYCODE_UNDOCK          = 207,
  KEYCODE_SUSPEND         = 165, // TODO: triggers something in hardware
  
  KEYCODE_BRIGHTNESS_UP   = 212,
  KEYCODE_BRIGHTNESS_DOWN = 101,

  KEYCODE_FN_KEY          = 227,
} t_thinkpad_keycodes;

/* all nvram toggle values are stored in bit 0 */
/* all xevents toggle values are stored in bit 1 */
typedef struct {
  unsigned int thinkpad_toggle;        /* ThinkPad button */
  unsigned int zoom_toggle;            /* zoom toggle */
  unsigned int display_toggle;         /* display toggle */
  unsigned int home_toggle;            /* Home button */
  unsigned int search_toggle;          /* Search button */
  unsigned int mail_toggle;            /* Mail button */
  unsigned int wireless_toggle;        /* Wireless button */
  unsigned int favorites_toggle;       /* Favorites button */
  unsigned int reload_toggle;          /* Reload button */
  unsigned int abort_toggle;           /* Abort button */
  unsigned int backward_toggle;        /* Backward button */
  unsigned int forward_toggle;         /* Forward button */
  unsigned int skip_backward_toggle;   /* media player skip backward button */
  unsigned int skip_forward_toggle;    /* media player skip forward button */
  unsigned int play_toggle;            /* media player play/pause button */
  unsigned int stop_toggle;            /* media player stop button */
  unsigned int volume_down_toggle;     /* volume up button */
  unsigned int volume_up_toggle;       /* volume down button */
  unsigned int lock_toggle;            /* lock button */
  unsigned int battery_toggle;         /* battery button */
  unsigned int sleep_toggle;           /* sleep button */
  unsigned int trackpoint_toggle;      /* switch trackpoint / touchpad button */
  unsigned int undock_toggle;          /* undock button */
  unsigned int suspend_toggle;         /* suspend button */
  unsigned int brightness_up_toggle;   /* brightness up button */
  unsigned int brightness_down_toggle; /* brightness down button */
  unsigned int fn_toggle;              /* Fn button */
  unsigned int thinklight_toggle;      /* ThinkLight */
  unsigned int hibernate_toggle;       /* hibernation/suspend toggle */
  unsigned int display_state;          /* display state */
  unsigned int expand_toggle;          /* hv expansion state */
  unsigned int brightness_level;       /* brightness level */
  unsigned int brightness_toggle;      /* brightness toggle */
  unsigned int volume_level;           /* volume level */
  unsigned int volume_toggle;          /* volume toggle */
  unsigned int mute_toggle;            /* mute toggle */
  unsigned int ac_state;               /* ac connected */
  unsigned int powermgt_ac;            /* power management mode ac */
  unsigned int powermgt_battery;       /* power management mode battery */
} t_thinkpad_state;

#endif /* __TPB_H__*/

/* vim600:set fen:set fdm=marker:set fdl=0: */
